@@ -3,7 +3,7 @@
 
 float inter4pol (short* buf, float index, long size);
 /*float inter4pol_stereo (short* buf, float index, long size);*/
-float inter4pol_float (float* buf, float index, long size);
+float inter4pol_float (float* buf, double index, long size);
 
 #endif /* __INTERPOL_H__ */
 
