@@ -363,7 +363,9 @@ void looperdata_set_playing(looper_data_t* data, int isplaying){
 	if (data) data->isplaying = isplaying;
 }
 void looperdata_set_recording(looper_data_t* data, int isrecording){
-	if (data) data->isrecording = isrecording;
+	if (!data) return;
+	if (buffer_get_type(data->buf) != BUFFER_TYPE_DISCSTREAM)
+		data->isrecording = isrecording;
 }
 
 int looperdata_get_playing(looper_data_t* data){
@@ -1011,7 +1013,7 @@ void looperdata_set_ngrains (looper_data_t* data, int ngrains){
 /*	printf ("ngrains:%d\n",ngrains);*/
 
 	if (ngrains){
-		data->grainindexes = realloc (data->grainindexes, sizeof(float) * ngrains);
+		data->grainindexes = realloc (data->grainindexes, sizeof(long) * ngrains);
 		data->grainoffsets = realloc (data->grainoffsets, sizeof(long) * ngrains);
 		data->grainsizes   = realloc (data->grainsizes, sizeof(long) * ngrains);
 		data->grainfadelengths = realloc (data->grainfadelengths, sizeof(long) * ngrains);
@@ -1445,12 +1447,12 @@ void looperdata_calc_sample_mono(looper_data_t* data, float* L){
 
 void looperdata_calc_sampleblock (looper_data_t* data, long size, float* Lbuf, float* Rbuf, float* Pbuf, int do_play, int do_rec){
 	long l;
-	long rp;
-	double pp;
+	/*long rp;*/
+	/*double pp;*/
 	if (!data->buf) return;
 
-	pp = data->playpos;
-	rp = data->recpos;	
+	/*pp = data->playpos;
+	rp = data->recpos;	*/
 
 	if ((size <= (data->recend - data->recstart) || !data->isrecording) && 
 		0 && /* this part is broken, use the single sample copy mode instead */
