@@ -68,15 +68,27 @@ static long path_pos_to_l(const char* path, int p){
 }
 
 osc_info_t* osc_info_new (speciallist_t* looperdatalist) {
-	lo_server_thread st 	= lo_server_thread_new("1783", osc_create_error);
-  	osc_info_t* oinfo	= malloc (sizeof (osc_info_t));
+	char port[5];
+	lo_server_thread st = NULL;
+  	osc_info_t* oinfo = calloc (sizeof (osc_info_t),1);
+	int i = 1783;
 
+	printf ("creating osc thread\n");
+
+	while ((++i < 1794) && !st){
+		sprintf (port,"%d",i);
+/*		st     = lo_server_thread_new(&port, osc_create_error);*/
+		st = lo_server_thread_new(port, NULL);
+	}
+
+	if (st) {printf ("osc server listening at port %s\n",port);}
+	else { printf ("failed to create osc server!.");}
+	
 	if (st){
   		oinfo->quit    		= 0;
 		oinfo->looperdatalist	= looperdatalist;
 		oinfo->st		= st;
 	
-		printf ("creating osc thread\n");
 		lo_server_thread_add_method(st, NULL,NULL,osc_data_handler, (void*)oinfo);
         	lo_server_thread_start(st);
 	}else{ free(oinfo); oinfo = NULL;}
