@@ -8,6 +8,7 @@
 #include "speciallist.h"
 enum {
         PD_STATUS_NEW,
+	PD_STATUS_TODO,
        	PD_STATUS_DONE,
         PD_STATUS_DEAD, 
         PD_STATUS_LAST
@@ -23,6 +24,7 @@ typedef struct _peakdata {
         signed char     *Lmax;
         signed char     *Rmin;
         signed char     *Rmax;
+	float		samplesperpixel;
 } peakdata_t;
 
 typedef struct _peakview {
@@ -43,6 +45,7 @@ void peakdata_set_status(peakdata_t *pd, int status);
 
 peakview_t* peakview_new(buffer_info_t* buf);
 void peakview_delete(peakview_t* view);
+void peakview_clear(peakview_t* view, long start, long end);
 void peakview_set_buffer(peakview_t* view,buffer_info_t* buf);
 
 void peakview_lock(peakview_t* view);
