@@ -1,5 +1,6 @@
 #include <pthread.h>
 #include <stdlib.h>
+#include <stdio.h>
 #include "speciallist.h"
 
 static speciallist_node_t* node_new(){
@@ -15,6 +16,8 @@ speciallist_t* speciallist_new (){
 	speciallist_t *list = malloc (sizeof(speciallist_t));
 	pthread_mutex_init (&list->mutex, NULL);
 	list->first = NULL;
+	list->last = NULL;
+	list->latest = NULL;
 	return list;
 }
 
@@ -123,11 +126,17 @@ int speciallist_append_nolock (speciallist_t *list, void *data){
         new->data = data;
 
         if (ptr){
+		list->last->next = new;
+		list->last = list->last->next;
+/*
                 while (ptr->next) ptr = ptr->next;
                 ptr->next = new;
+*/
                 return 1;
         }
+	list->latest = new;
         list->first = new;
+	list->last = new;
         return 1;
 }
 
@@ -135,19 +144,28 @@ int speciallist_delete_nolock (speciallist_t *list, void *data){
 	speciallist_node_t *found;
 	speciallist_node_t *last;
 
+	if (!list) return 0;
 	if (!list->first || !data) return 0;
 
 	if (list->first->data == data){
 		found = list->first;
+		if (list->last == list->first)
+			list->last = NULL;
+		if (list->latest == list->first)
+			list->latest = list->first->next;
 		list->first = list->first->next;
 		free(found);
 		return 1;
 	}
 
-	last = list->first;	
+	last = list->first;
 	found = list->first->next;		
 	while (found){
 		if (found->data == data){
+			if (found == list->last)
+				list->last = last;
+			if (found == list->latest)
+				list->latest = list->first;
 			last->next = found->next;
 			free(found);
 			return 1;
@@ -165,6 +183,7 @@ void* speciallist_get_first_nolock (speciallist_t *list){
 }
 
 void* speciallist_get_last_nolock (speciallist_t *list){
+/*
 	speciallist_node_t *ptr;
 	speciallist_node_t *rptr = NULL;
 
@@ -175,22 +194,50 @@ void* speciallist_get_last_nolock (speciallist_t *list){
 	}
 	if (rptr) return rptr->data;
 	else return NULL;
+*/
+	return list->last->data;
 }
 
 void* speciallist_get_next_nolock (speciallist_t *list, void *data){
 	speciallist_node_t *ptr;
 
-	if (!list->first || !data) return NULL;
+	if (!list) return NULL;
+	if (!data) return NULL;
+	if (!list->first) return NULL;
+	if (list->first == list->last) return NULL; /* only one member -> no next */
 
+	if (!list->latest) {printf ("no list->latest\n"); return NULL;} /* this should not happen */
+
+	if (list->latest->data != data)
+		list->latest = list->first;
+
+	ptr = list->latest;
+	while (ptr){
+		if (ptr->data == data) {
+                        if (ptr->next){
+                                list->latest = ptr->next;
+                                return ptr->next->data;
+                        } else {
+				list->latest = list->first;
+				return NULL;
+			}
+                }
+                ptr = ptr->next;
+	}
+
+/*
 	ptr = list->first;
 	while(ptr){
 		if (ptr->data == data) {
-			if (ptr->next)
+			if (ptr->next){
+				list->latest = ptr->next;
 				return ptr->next->data;
-			else return NULL;
+			}
+			else return list->latest = NULL;
 		}
 		ptr = ptr->next;
 	}		
+*/
 	return NULL;
 }
 
@@ -198,13 +245,19 @@ void* speciallist_get_previous_nolock (speciallist_t *list, void *data){
         speciallist_node_t *ptr;
 	speciallist_node_t *rptr = NULL;
 
+	if (!list) return NULL;
         if (!list->first || !data) return NULL;
 
         ptr = list->first;
         while(ptr){
                 if (ptr->data == data) {
-			if (rptr) return rptr->data;
-        		else return NULL;
+			if (rptr){
+				list->latest = rptr;
+			 	return rptr->data;
+        		} else {
+				list->latest = list->first;
+				return NULL;
+			}
                 }
 		rptr = ptr;
                 ptr = ptr->next;
