@@ -664,7 +664,7 @@ void gtk_loopview_update_cursorposition (GtkLoopview *loopview){
 
 static void gtk_loopview_realize (GtkWidget *widget)
 {
-  	GtkLoopview *loopview;
+  	/*GtkLoopview *loopview;*/
   	GdkWindowAttr attributes;
   	gint attributes_mask;
 
@@ -672,7 +672,7 @@ static void gtk_loopview_realize (GtkWidget *widget)
   	g_return_if_fail (GTK_IS_LOOPVIEW (widget));
 	
   	GTK_WIDGET_SET_FLAGS (widget, GTK_REALIZED);
-  	loopview = GTK_LOOPVIEW (widget);
+  	/*loopview = GTK_LOOPVIEW (widget);*/
 	
   	attributes.x = widget->allocation.x;
   	attributes.y = widget->allocation.y;
@@ -1161,7 +1161,22 @@ static gboolean gtk_loopview_button_press( GtkWidget *widget,
 
 	loopview->button = event->button;
 
-	if ((event->button == 1) && (event->state & GDK_CONTROL_MASK)){
+	if ((event->button == 1) && (event->state & GDK_CONTROL_MASK) && (event->state & GDK_MOD1_MASK)){
+                if (loopview->looperdata->buf){
+                        gettimeofday(&loopview->lastmousetime,0);
+                        looperdata_lock(loopview->looperdata);
+                        looperdata_set_playpos(loopview->looperdata,
+				looperdata_get_loopstart(loopview->looperdata));
+                        looperdata_unlock(loopview->looperdata);
+                        t1 = loopview->gplaypos;
+                        loopview->gplaypos = gtk_loopview_sample2graphical(loopview,
+                                                looperdata_get_playpos(loopview->looperdata));
+                        gtk_loopview_update_area(loopview,t1,t1);
+                        gtk_loopview_update_area(loopview,loopview->gplaypos,loopview->gplaypos);
+                        loopview->grabsel = 6 ; /* "scratch" with playhead */
+                        loopview->speedbeforescratch = loopview->looperdata->speed;
+                }
+	} else if ((event->button == 1) && (event->state & GDK_CONTROL_MASK)){
 		if (loopview->looperdata->buf){
 			gettimeofday(&loopview->lastmousetime,0);
 			looperdata_lock(loopview->looperdata);
@@ -1180,7 +1195,7 @@ static gboolean gtk_loopview_button_press( GtkWidget *widget,
 			loopview->grabsel = 6 ; /* "scratch" with playhead */
 			loopview->speedbeforescratch = loopview->looperdata->speed;
 		}
-	}else if (event->button == 1){
+	} else if (event->button == 1){
 		/* change selection */
 		sdiff = loopview->gloopstart - event->x;
 		ediff = event->x - loopview->gloopend;
@@ -1192,25 +1207,25 @@ static gboolean gtk_loopview_button_press( GtkWidget *widget,
 			loopview->grabsel = 1; /* grab the start */
 			cursor = gdk_cursor_new(GDK_LEFT_SIDE);
 			gdk_window_set_cursor(widget->window,cursor);
-		}else if (((ediff < maxd) && (ediff >= 0)) ||
+		} else if (((ediff < maxd) && (ediff >= 0)) ||
 			((ediff <= 0) && (ediff  > (maxd * -1)
 				&& (sdiff <(bdiff / 8 ))))){
 			/* resize gloopend */
 			cursor = gdk_cursor_new(GDK_RIGHT_SIDE);
 			gdk_window_set_cursor(widget->window,cursor);
 			loopview->grabsel = 2; /* grab the end */
-		}else if ((event->x > loopview->gloopstart) && (event->x <loopview->gloopend)){
+		} else if ((event->x > loopview->gloopstart) && (event->x <loopview->gloopend)){
 			/* move and resize the whole selection */
 			cursor = gdk_cursor_new(GDK_FLEUR);
 			gdk_window_set_cursor(widget->window,cursor);
 			if (event->state & GDK_SHIFT_MASK){	
-				loopview->grabsel = 5; /* grab the whole loop,  dont resize*/
-			}else{
+				loopview->grabsel = 5; /* grab the whole loop, dont resize*/
+			} else {
 				loopview->grabsel = 3;/* grab the whole loop */
 			}
 			loopview->lastmouseX = event->x;
 			loopview->lastmouseY = event->y;
-		}else{
+		} else {
 			/* new selection */
 			t1 = loopview->gloopstart;
 			t2 = loopview->gloopend;
@@ -1228,7 +1243,7 @@ static gboolean gtk_loopview_button_press( GtkWidget *widget,
 
                         gtk_loopview_update_area(loopview,t1,t2);
 		}
-	}else if (event->button == 2){
+	} else if (event->button == 2){
 		if (event->state & GDK_SHIFT_MASK){
 			loopview->grabsel = 2;
 		}else{
@@ -1244,7 +1259,14 @@ static gboolean gtk_loopview_button_press( GtkWidget *widget,
 
 		/* LATER: menu for ctr-button:
 		http://developer.gnome.org/doc/API/2.0/gtk/GtkMenu.html#gtk-menu-popup*/
-
+	} else if ((event->button == 3) && (event->state & GDK_CONTROL_MASK) && (event->state & GDK_MOD1_MASK)){
+                if (loopview->looperdata->buf){
+                        looperdata_lock(loopview->looperdata);
+                        /*looperdata_set_recpos(loopview->looperdata,
+                                (double)gtk_loopview_graphical2sample(loopview,event->x));*/
+			looperdata_set_recpos(loopview->looperdata,looperdata_get_recstart(loopview->looperdata));
+                        looperdata_unlock(loopview->looperdata);
+                }
 	} else if ((event->button == 3) && (event->state & GDK_CONTROL_MASK)){
 		if (loopview->looperdata->buf){
 			looperdata_lock(loopview->looperdata);
@@ -1472,7 +1494,7 @@ static gboolean gtk_loopview_motion_notify( GtkWidget      *widget,
 
 static void gtk_loopview_update_mouse (GtkLoopview *loopview, gint x, gint y)
 {
-	gint looplen;
+	/*gint looplen;*/
 	gint resize;
 	gint tmp,t1,t2,t3,t4;
 	suseconds_t tdiff;
@@ -1507,10 +1529,12 @@ static void gtk_loopview_update_mouse (GtkLoopview *loopview, gint x, gint y)
 				gtk_loopview_update_area(loopview,tmp,loopview->gloopend);
 				break;
 			case 3:
-				looplen = loopview->gloopend - loopview->gloopstart;
+				/*looplen = loopview->gloopend - loopview->gloopstart;*/
 				resize = y - loopview->lastmouseY;
 	
 				t1 = loopview->gloopstart + 1 + x - loopview->lastmouseX - resize;
+				/* should ifnd a better way to make the start really at 0 */
+				if (loopview->gloopstart < 2) loopview->gloopstart = 0;
 				t2 = loopview->gloopstart;
 				t3 = loopview->gloopend + 1 + x - loopview->lastmouseX + resize;
 				t4 = loopview->gloopend;
@@ -1624,7 +1648,7 @@ static void gtk_loopview_update_mouse (GtkLoopview *loopview, gint x, gint y)
 				gtk_loopview_update_area(loopview,tmp,loopview->grecend);
 				break;
 			case 3:
-				looplen = loopview->grecend - loopview->grecstart;
+				/*looplen = loopview->grecend - loopview->grecstart;*/
 				resize = y - loopview->lastmouseY;
 							
 				t1 = loopview->grecstart + 1 + x - loopview->lastmouseX - resize;
