@@ -431,6 +431,15 @@ gint main_idlefunc(gpointer data){
 					config_read_looper (ch,looper);
 			tmpptr = g_list_next(tmpptr);
 		}
+		tmpptr = g_list_first (looperlist->listptr);
+                /* do it twice to get the order of loopers right: */
+		while (tmpptr){
+                        looper = (looper_gui_t*)tmpptr->data;
+                        if (looper != NULL)
+                                if (looper->id)
+                                        config_read_looper (ch,looper);
+                        tmpptr = g_list_next(tmpptr);
+                }
 		config_get_geometry(ch, &x,&y,&w,&h);
                 gtk_window_move((GtkWindow*)window,x,y);
                 gtk_window_resize((GtkWindow*)window,w,h);
@@ -647,7 +656,7 @@ static void open_project (char *filename){
 
 static void about_callback(gpointer data){
 	GtkWidget *dialog;
-	gint response;  
+	/*gint response;  */
                  
         dialog = gtk_message_dialog_new (GTK_WINDOW(window),
                                 GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -656,7 +665,7 @@ static void about_callback(gpointer data){
                                	"kluppe looper is developed by dieter kovacic\n"
 				"http://kluppe.klingt.org\n"
                         	"contact: kluppe" "@" "klingt.org.\n");
-        response = gtk_dialog_run (GTK_DIALOG (dialog));
+        /*response = */ gtk_dialog_run (GTK_DIALOG (dialog));
                         
         gtk_widget_destroy (dialog);
 }
@@ -1075,8 +1084,8 @@ int main(int argc, char *argv[])
 	/* start the jack threads */
         jack_info = mixer_launch(looperdatalist);
 
-        g_thread_init(NULL);
-        gdk_threads_init();
+        /*g_thread_init(NULL);*/
+        /* gdk_threads_init();*/
 /*        gdk_threads_enter();*/
 
 	gtk_init(&argc, &argv);
